==> deverhood-react-1.16.51.tgz: package/src/reducers/form.js <==
import { FORM_API } from "../actions/actionType";
import Super from "./super";
import moment from "moment";
const defaultState = {
  list: [],
  data: {},
  forms: [],
  response: {},
  item: {},
  answers: [],
  responses: [],
  equations: [],
  equation: {},
  stats: [],
  tags: [],
  export: {},
  response_recent: {},
  answers_recent: []
};

export default (state = defaultState, action) => {
  let reducer = new Super(state, action);
  switch (action.type) {
    case FORM_API.SELF.CLEAR.SUCCESS:
      return {
        ...state,
        list: [],
        responses: [],
        response: {},
        data: {},
        stats: []
      };
    case FORM_API.SELF.GET.SUCCESS:
      return { ...reducer.get(), forms: [...reducer.get().data.items] };
    case FORM_API.RESPONSE.GET.SUCCESS:
      return {
        ...reducer.get("response"),
        answers: [...reducer.get("response").response.itemResponses]
      };
    case FORM_API.RESPONSE_RECENT.GET.SUCCESS:
      return {
        ...reducer.get("response_recent"),
        answers_recent: [
          ...reducer.get("response_recent").response_recent.itemResponses
        ]
      };
    case FORM_API.SELF.ALL.SUCCESS:
      return reducer.list();
    case FORM_API.CLEAR.ALL.SUCCESS:
      return reducer.clear();
    case FORM_API.RESPONSE.ALL.SUCCESS:
      return reducer.list("responses");
    case FORM_API.SELF.POST.SUCCESS:
      return reducer.post();
    case FORM_API.SELF.PUT.SUCCESS:
      return reducer.put();
    case FORM_API.SELF.DEL.SUCCESS:
      return reducer.delete();
    case FORM_API.TEXT.POST.SUCCESS:
      var index = 0;
      var forms = state.forms;
      for (var i in forms) {
        if (forms[i].id === action.beforeItemId) {
          index = i;
          break;
        }
      }
      forms.splice(index, 0, action.data);
      return { ...state, forms: forms };
    case FORM_API.TEXT.PUT.SUCCESS:
      return reducer.put("form", "forms");
    case FORM_API.LIST.PUT.SUCCESS:
      return reducer.put("form", "forms");
    case FORM_API.SECTION_HEADER.PUT.SUCCESS:
      return reducer.put("form", "forms");
    case FORM_API.CHECKBOX.PUT.SUCCESS:
      return reducer.put("form", "forms");
    case FORM_API.MULTIPLE_CHOICE.PUT.SUCCESS:
      return reducer.put("form", "forms");
    case FORM_API.DATE.PUT.SUCCESS:
      return reducer.put("form", "forms");
    case FORM_API.DATETIME.PUT.SUCCESS:
      return reducer.put("form", "forms");
    case FORM_API.TIME.PUT.SUCCESS:
      return reducer.put("form", "forms");
    case FORM_API.SCALE.PUT.SUCCESS:
      return reducer.put("form", "forms");
    case FORM_API.IMAGE.PUT.SUCCESS:
      return reducer.put("form", "forms");
    case FORM_API.VIDEO.PUT.SUCCESS:
      return reducer.put("form", "forms");
    case FORM_API.CHECKBOX_GRID.PUT.SUCCESS:
      return reducer.put("form", "forms");
    case FORM_API.DROPDOWN.PUT.SUCCESS:
      return reducer.put("form", "forms");
    case FORM_API.GRID.PUT.SUCCESS:
      return reducer.put("form", "forms");
    case FORM_API.ITEM.DEL.SUCCESS:
      return reducer.delete("forms");
    case FORM_API.TYPE.PUT.SUCCESS:
      return {
        ...state,
        forms: state.forms.map(v =>
          v.id === action.data.id ? { ...action.data } : { ...v }
        )
      };
    case FORM_API.RESPONSE.POST.SUCCESS:
      return reducer.post("responses");
    case FORM_API.RESPONSE.DEL.SUCCESS:
      return reducer.delete("responses");
    case FORM_API.ITEM.POST.SUCCESS:
      return state.answers.filter(v => v.id.itemId === action.data.id.itemId)
        .length == 0
        ? { ...state, answers: [...state.answers, action.data] }
        : {
            ...state,
            answers: state.answers.map(v =>
              v.id.itemId === action.data.id.itemId
                ? { ...action.data }
                : { ...v }
            )
          };
    case FORM_API.EQUATION.ALL.SUCCESS:
      return {
        ...state,
        equations: action.data.map(v => ({
          ...v,
          value: v.value
            .replace("function evaluate(){ ", "")
            .substring(0, v.value.length - 1)
        }))
      };
    case FORM_API.EQUATION.GET.SUCCESS:
      var str = action.data.value
        ? action.data.value.replace("function evaluate(){ ", "")
        : "";
      return {
        ...state,
        equation: {
          ...action.data,
          value: str.substring(0, str.length - 1)
        }
      };
    case FORM_API.EQUATION.POST.SUCCESS:
      return reducer.post("equations");
    case FORM_API.EQUATION.PUT.SUCCESS:
      return reducer.put("equation", "equations");
    case FORM_API.EQUATION.DEL.SUCCESS:
      return reducer.delete("equations");
    case FORM_API.STAT.GET.SUCCESS:
      return reducer.list("stats");
    case FORM_API.TAG.ALL.SUCCESS:
      return {
        ...state,
        tags: action.data
      };
    case FORM_API.CONDITION.POST.SUCCESS:
      return {
        ...state,
        equation: {
          ...state.equation,
          conditions: [...state.equation.conditions, action.data]
        }
      };
    case FORM_API.CONDITION.PUT.SUCCESS:
      return {
        ...state,
        equation: {
          ...state.equation,
          conditions: state.equation.conditions.map(v =>
            v.id === action.data.id ? { ...action.data } : { ...v }
          )
        }
      };
    case FORM_API.CONDITION.DEL.SUCCESS:
      return {
        ...state,
        equation: {
          ...state.equation,
          conditions: state.equation.conditions.filter(
            v => v.id !== action.data
          )
        }
      };
    case FORM_API.STAT_GROUP.ALL.SUCCESS:
      return {
        ...state,
        stats: action.data
      };
    case FORM_API.EXPORT_CSV.ALL.SUCCESS:
      return {
        ...state,
        export: action.data
      };
    default:
      return state;
  }
};

==> deverhood-react-1.16.59.tgz: package/src/reducers/form.js <==
import { FORM_API } from "../actions/actionType";
import Super from "./super";
const defaultState = {
  list: [],
  data: {},
  forms: [],
  response: {},
  item: {},
  answers: [],
  responses: [],
  equations: [],
  equation: {},
  stats: [],
  tags: [],
  export: {},
  response_recent: {},
  answers_recent: [],
  responsed_student: []
};

export default (state = defaultState, action) => {
  let reducer = new Super(state, action);
  switch (action.type) {
    case FORM_API.SELF.CLEAR.SUCCESS:
      return {
        ...state,
        list: [],
        responses: [],
        response: {},
        data: {},
        stats: [],
        stat: []
      };
    case FORM_API.SELF.GET.SUCCESS:
      return { ...reducer.get(), forms: [...reducer.get().data.items] };
    case FORM_API.RESPONSE.GET.SUCCESS:
      return {
        ...reducer.get("response"),
        answers: [...reducer.get("response").response.itemResponses],
        forms: action.data.form ? action.data.form.items : []
      };
    case FORM_API.RESPONSE_RECENT.GET.SUCCESS:
      return {
        ...reducer.get("response_recent"),
        answers_recent: [
          ...reducer.get("response_recent").response_recent.itemResponses
        ]
      };
    case FORM_API.SELF.ALL.SUCCESS:
      return reducer.list();
    case FORM_API.RESPONSED_STUDENT.ALL.SUCCESS:
      return {
        ...state,
        responsed_student: action.data
      };
    case FORM_API.CLEAR.ALL.SUCCESS:
      return reducer.clear();
    case FORM_API.RESPONSE.ALL.SUCCESS:
      return reducer.list("responses");
    case FORM_API.SELF.POST.SUCCESS:
      return reducer.post();
    case FORM_API.SELF.PUT.SUCCESS:
      return reducer.put();
    case FORM_API.SELF.DEL.SUCCESS:
      return reducer.delete();
    case FORM_API.TEXT.POST.SUCCESS:
      var index = 0;
      var forms = state.forms;
      for (var i in forms) {
        if (forms[i].id === action.beforeItemId) {
          index = i;
          break;
        }
      }
      forms.splice(index, 0, action.data);
      return { ...state, forms: forms };
    case FORM_API.TEXT.PUT.SUCCESS:
      return reducer.put("form", "forms");
    case FORM_API.LIST.PUT.SUCCESS:
      return reducer.put("form", "forms");
    case FORM_API.SECTION_HEADER.PUT.SUCCESS:
      return reducer.put("form", "forms");
    case FORM_API.CHECKBOX.PUT.SUCCESS:
      return reducer.put("form", "forms");
    case FORM_API.MULTIPLE_CHOICE.PUT.SUCCESS:
      return reducer.put("form", "forms");
    case FORM_API.DATE.PUT.SUCCESS:
      return reducer.put("form", "forms");
    case FORM_API.DATETIME.PUT.SUCCESS:
      return reducer.put("form", "forms");
    case FORM_API.TIME.PUT.SUCCESS:
      return reducer.put("form", "forms");
    case FORM_API.SCALE.PUT.SUCCESS:
      return reducer.put("form", "forms");
    case FORM_API.IMAGE.PUT.SUCCESS:
      return reducer.put("form", "forms");
    case FORM_API.VIDEO.PUT.SUCCESS:
      return reducer.put("form", "forms");
    case FORM_API.CHECKBOX_GRID.PUT.SUCCESS:
      return reducer.put("form", "forms");
    case FORM_API.DROPDOWN.PUT.SUCCESS:
      return reducer.put("form", "forms");
    case FORM_API.GRID.PUT.SUCCESS:
      return reducer.put("form", "forms");
    case FORM_API.ITEM.DEL.SUCCESS:
      return reducer.delete("forms");
    case FORM_API.TYPE.PUT.SUCCESS:
      return {
        ...state,
        forms: state.forms.map(v =>
          v.id === action.data.id ? { ...action.data } : { ...v }
        )
      };
    case FORM_API.RESPONSE.POST.SUCCESS:
      return reducer.post("responses");
    case FORM_API.RESPONSE.DEL.SUCCESS:
      return reducer.delete("responses");
    case FORM_API.ITEM.POST.SUCCESS:
      return state.answers.filter(v => v.id.itemId === action.data.id.itemId)
        .length == 0
        ? { ...state, answers: [...state.answers, action.data] }
        : {
            ...state,
            answers: state.answers.map(v =>
              v.id.itemId === action.data.id.itemId
                ? { ...action.data }
                : { ...v }
            )
          };
    case FORM_API.EQUATION.ALL.SUCCESS:
      return {
        ...state,
        equations: action.data.map(v => ({
          ...v,
          value: v.value
            .replace("function evaluate(){ ", "")
            .substring(0, v.value.length - 1)
        }))
      };
    case FORM_API.EQUATION.GET.SUCCESS:
      var str = action.data.value
        ? action.data.value.replace("function evaluate(){ ", "")
        : "";
      return {
        ...state,
        equation: {
          ...action.data,
          value: str.substring(0, str.length - 1)
        }
      };
    case FORM_API.EQUATION.POST.SUCCESS:
      return reducer.post("equations");
    case FORM_API.EQUATION.PUT.SUCCESS:
      return reducer.put("equation", "equations");
    case FORM_API.EQUATION.DEL.SUCCESS:
      return reducer.delete("equations");
    case FORM_API.STAT.GET.SUCCESS:
      return { ...state, stats: action.data };
    case FORM_API.STUDENT.GET.SUCCESS:
      return reducer.list("stats");
    case FORM_API.TAG.ALL.SUCCESS:
      return {
        ...state,
        tags: action.data
      };
    case FORM_API.CONDITION.POST.SUCCESS:
      return {
        ...state,
        equation: {
          ...state.equation,
          conditions: [...state.equation.conditions, action.data]
        }
      };
    case FORM_API.CONDITION.PUT.SUCCESS:
      return {
        ...state,
        equation: {
          ...state.equation,
          conditions: state.equation.conditions.map(v =>
            v.id === action.data.id ? { ...action.data } : { ...v }
          )
        }
      };
    case FORM_API.CONDITION.DEL.SUCCESS:
      return {
        ...state,
        equation: {
          ...state.equation,
          conditions: state.equation.conditions.filter(
            v => v.id !== action.data
          )
        }
      };
    case FORM_API.STAT_GROUP.ALL.SUCCESS:
      return {
        ...state,
        stats: action.data
      };
    case FORM_API.EXPORT_CSV.ALL.SUCCESS:
      return {
        ...state,
        export: action.data
      };
    default:
      return state;
  }
};
